@@ -92,7 +92,7 @@ class ActOne(Level):
                     )
 
                 if col == "$":
-                    self.target = Target((x, y))
+                    self.target = Target((x, y), self.visible_sprites)
 
                 if col == "#":
                     PropTile((x, y), self.visible_sprites)
@@ -114,6 +114,8 @@ class ActOne(Level):
             collision_sprites=self.collision_sprites,
             visible_sprites=self.visible_sprites,
             active_sprites=self.active_sprites,
+            enemy_sprites=self.enemy_sprites,
+            can_shoot=False,
         )
 
     def play_bgm(self, path: str) -> None:
